class OverwriteError(Exception):
    pass


class AccountDoesNotExist(Exception):
    pass


class BadPassphrase(Exception):
    pass


class DecryptionFailed(Exception):
    pass
